.. _manual:

.. raw:: html

    <br><br>

.. title:: Manual


**NAME**

    ``KAMER`` - Bejaarden en Gehandicapten (Wzd), Criminelen (Wfz), Psychiatrische Patienten (WvGGz)


**SYNOPSIS**

    ::

        kamer req


**DESCRIPTION**


    Op 20 Oktober 2012 heb ik na correspondentie met de Koningin een klacht tegen de Nederland ingedient (Thate tegen Nederland 69389/12). De klacht betrof het falen van de
    (F)ACT methodiek, de methode die GGZ Nederland gebruikt om vorm te geven aan de wetten die gedwongen behandeling in Nederland mogelijk maken. De uitspraak is niet-ontvankelijk.


**INSTALL**

    ::

        $ pipx install kamer
        $ pipx ensurepath

        <new terminal>

**USAGE**

    show request to the prosecutor

    ::

        $ kamer req
        Information and Evidence Unit
        Office of the Prosecutor
        Post Office Box 19519
        2500 CM The Hague
        The Netherlands


**FILES**

    ::

        ~/.kamer 
        ~/.local/pipx/venvs/kamer/*


**AUTHOR**

    Bart Thate <bthate@dds.nl>


**COPYRIGHT**

    ``KAMER`` is Public Domain.
